==> istio-model-v1alpha3-6.4.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterPatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterPatchFluentImpl<A extends EnvoyFilterPatchFluent<A>> extends BaseFluent<A> implements EnvoyFilterPatchFluent<A>{
  public EnvoyFilterPatchFluentImpl() {
  }
  public EnvoyFilterPatchFluentImpl(EnvoyFilterPatch instance) {
    this.withFilterClass(instance.getFilterClass()); 
    this.withOperation(instance.getOperation()); 
    this.withValue(instance.getValue()); 
  }
  private EnvoyFilterPatchFilterClass filterClass;
  private EnvoyFilterPatchOperation operation;
  private Map<String,Object> value;
  public EnvoyFilterPatchFilterClass getFilterClass() {
    return this.filterClass;
  }
  public A withFilterClass(EnvoyFilterPatchFilterClass filterClass) {
    this.filterClass=filterClass; return (A) this;
  }
  public Boolean hasFilterClass() {
    return this.filterClass != null;
  }
  public EnvoyFilterPatchOperation getOperation() {
    return this.operation;
  }
  public A withOperation(EnvoyFilterPatchOperation operation) {
    this.operation=operation; return (A) this;
  }
  public Boolean hasOperation() {
    return this.operation != null;
  }
  public A addToValue(String key,Object value) {
    if(this.value == null && key != null && value != null) { this.value = new LinkedHashMap(); }
    if(key != null && value != null) {this.value.put(key, value);} return (A)this;
  }
  public A addToValue(Map<String,Object> map) {
    if(this.value == null && map != null) { this.value = new LinkedHashMap(); }
    if(map != null) { this.value.putAll(map);} return (A)this;
  }
  public A removeFromValue(String key) {
    if(this.value == null) { return (A) this; }
    if(key != null && this.value != null) {this.value.remove(key);} return (A)this;
  }
  public A removeFromValue(Map<String,Object> map) {
    if(this.value == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.value != null){this.value.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getValue() {
    return this.value;
  }
  public <K,V>A withValue(Map<String,Object> value) {
    if (value == null) { this.value =  null;} else {this.value = new LinkedHashMap(value);} return (A) this;
  }
  public Boolean hasValue() {
    return this.value != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EnvoyFilterPatchFluentImpl that = (EnvoyFilterPatchFluentImpl) o;
    if (filterClass != null ? !filterClass.equals(that.filterClass) :that.filterClass != null) return false;
    if (operation != null ? !operation.equals(that.operation) :that.operation != null) return false;
    if (value != null ? !value.equals(that.value) :that.value != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(filterClass,  operation,  value,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (filterClass != null) { sb.append("filterClass:"); sb.append(filterClass + ","); }
    if (operation != null) { sb.append("operation:"); sb.append(operation + ","); }
    if (value != null && !value.isEmpty()) { sb.append("value:"); sb.append(value); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterPatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterPatchFluentImpl<A extends EnvoyFilterPatchFluent<A>> extends BaseFluent<A> implements EnvoyFilterPatchFluent<A>{
  public EnvoyFilterPatchFluentImpl() {
  }
  public EnvoyFilterPatchFluentImpl(EnvoyFilterPatch instance) {
    if (instance != null) {
      this.withFilterClass(instance.getFilterClass());
      this.withOperation(instance.getOperation());
      this.withValue(instance.getValue());
    }
  }
  private EnvoyFilterPatchFilterClass filterClass;
  private EnvoyFilterPatchOperation operation;
  private Map<String,Object> value;
  public EnvoyFilterPatchFilterClass getFilterClass() {
    return this.filterClass;
  }
  public A withFilterClass(EnvoyFilterPatchFilterClass filterClass) {
    this.filterClass=filterClass; return (A) this;
  }
  public Boolean hasFilterClass() {
    return this.filterClass != null;
  }
  public EnvoyFilterPatchOperation getOperation() {
    return this.operation;
  }
  public A withOperation(EnvoyFilterPatchOperation operation) {
    this.operation=operation; return (A) this;
  }
  public Boolean hasOperation() {
    return this.operation != null;
  }
  public A addToValue(String key,Object value) {
    if(this.value == null && key != null && value != null) { this.value = new LinkedHashMap(); }
    if(key != null && value != null) {this.value.put(key, value);} return (A)this;
  }
  public A addToValue(Map<String,Object> map) {
    if(this.value == null && map != null) { this.value = new LinkedHashMap(); }
    if(map != null) { this.value.putAll(map);} return (A)this;
  }
  public A removeFromValue(String key) {
    if(this.value == null) { return (A) this; }
    if(key != null && this.value != null) {this.value.remove(key);} return (A)this;
  }
  public A removeFromValue(Map<String,Object> map) {
    if(this.value == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.value != null){this.value.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getValue() {
    return this.value;
  }
  public <K,V>A withValue(Map<String,Object> value) {
    if (value == null) { this.value =  null;} else {this.value = new LinkedHashMap(value);} return (A) this;
  }
  public Boolean hasValue() {
    return this.value != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterPatchFluentImpl that = (EnvoyFilterPatchFluentImpl) o;
    if (!java.util.Objects.equals(filterClass, that.filterClass)) return false;

    if (!java.util.Objects.equals(operation, that.operation)) return false;

    if (!java.util.Objects.equals(value, that.value)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(filterClass,  operation,  value,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (filterClass != null) { sb.append("filterClass:"); sb.append(filterClass + ","); }
    if (operation != null) { sb.append("operation:"); sb.append(operation + ","); }
    if (value != null && !value.isEmpty()) { sb.append("value:"); sb.append(value); }
    sb.append("}");
    return sb.toString();
  }
  
}
